==> apache-streampipes-0.68.0-incubating-source-release.zip: apache-streampipes-0.68.0-incubating/streampipes-connect-container-worker/src/test/java/org/apache/streampipes/connect/container/worker/utils/Utils.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.streampipes.connect.container.worker.utils;

import org.apache.streampipes.model.connect.adapter.AdapterSetDescription;
import org.apache.streampipes.model.connect.adapter.AdapterStreamDescription;
import org.apache.streampipes.model.connect.adapter.GenericAdapterSetDescription;
import org.apache.streampipes.model.connect.adapter.GenericAdapterStreamDescription;

import java.util.ArrayList;

public class Utils {

    public static AdapterStreamDescription getMinimalStreamAdapter() {
        AdapterStreamDescription result = new GenericAdapterStreamDescription();
        String id = "http://t.de/";
        result.setUri(id);
        result.setId(id);
        result.setRules(new ArrayList<>());

        return result;
    }

    public static AdapterSetDescription getMinimalSetAdapter() {
        AdapterSetDescription result = new GenericAdapterSetDescription();
        String id = "http://t.de/";
        result.setUri(id);
        result.setId(id);

        return result;
    }
}

==> apache-streampipes-0.69.0-incubating-source-release.zip: apache-streampipes-0.69.0-incubating/streampipes-connect-container-worker/src/test/java/org/apache/streampipes/connect/container/worker/utils/Utils.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.streampipes.connect.container.worker.utils;

import org.apache.streampipes.model.connect.adapter.AdapterSetDescription;
import org.apache.streampipes.model.connect.adapter.AdapterStreamDescription;
import org.apache.streampipes.model.connect.adapter.GenericAdapterSetDescription;
import org.apache.streampipes.model.connect.adapter.GenericAdapterStreamDescription;

import java.util.ArrayList;

public class Utils {

    public static AdapterStreamDescription getMinimalStreamAdapter() {
        AdapterStreamDescription result = new GenericAdapterStreamDescription();
        String id = "http://t.de/";
        result.setElementId(id);
        result.setRules(new ArrayList<>());

        return result;
    }

    public static AdapterSetDescription getMinimalSetAdapter() {
        AdapterSetDescription result = new GenericAdapterSetDescription();
        String id = "http://t.de/";
        result.setElementId(id);

        return result;
    }
}
